/**
 * @file DynamicServiceMgr.hh
 *
 * @brief  DIET DynamicSeD header
 *
 * @author  Benjamin Depardon (benjamin.depardon@ens-lyon.fr)
 *
 * @section Licence
 *
 * Copyright ENS Lyon, INRIA, UCBL, SysFera (2000)
 *
 * - Frederic.Desprez@ens-lyon.fr (Project Manager)
 * - Eddy.Caron@ens-lyon.fr (Technical Manager)
 * - Tech@sysfera.com (Maintainer and Technical Support)
 *
 * This software is a computer program whose purpose is to provide an
 * easy and transparent access to distributed and heterogeneous
 * platforms.
 *
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided
 * only with a limited warranty  and the software's author,  the holder
 * of the economic rights,  and the successive licensors  have only
 * limited liability.
 *
 * In this respect, the user's attention is drawn to the risks
 * associated with loading,  using,  modifying and/or developing or
 * reproducing the software by the user in light of its specific status
 * of free software, that may mean  that it is complicated to
 * manipulate, and  that  also therefore means  that it is reserved for
 * developers and experienced professionals having in-depth computer
 * knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions
 * enabling the security of their systems and/or data to be ensured and,
 * more generally, to use and operate it in the same conditions as
 * regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */


#ifndef _DYNAMICSED_HH_
#define _DYNAMICSED_HH_

#include <map>
#include <string>

#include "DIET_server.h"

/** Utility macro to simplify the user source code. */
#define DYNAMICSERVICEMGR_CLASS(T)                      \
  extern "C" DynamicServiceMgr * constructor() {         \
    return new(T) ();                                   \
  }                                                     \
  extern "C" void destructor(DynamicServiceMgr * ds) {   \
    delete ds;                                          \
  }


/** A simple exception when a module failed to be loaded. */
class InstanciationError {
public:
  explicit
  InstanciationError(const char *error)
    : errorCode(error) {
  }

  InstanciationError(const InstanciationError &error)
    : errorCode(error.errorCode) {
  }

  const char *
  message() const {
    return errorCode;
  }

private:
  const char *errorCode;
};


typedef std::map<std::string, void *> map_string_void_t;

/** The DynamicServiceMgr class declaration. */
class DynamicServiceMgr {
public:
  DynamicServiceMgr();

  ~DynamicServiceMgr();

  int
  addServiceMgr(const std::string &lib);

  int
  removeServiceMgr(const std::string &name);

private:
  typedef int service (diet_profile_t *);
  typedef int addService ();
  typedef int removeService ();
  typedef const char *const serviceName ();

  /** These two methods are obtained from the loaded module. */
  map_string_void_t services;
};

#endif  // _DYNAMICSED_HH_
