/**
* @file DagNodeLauncher.cc
*
* @brief  TThe virtual class used for dagNode execution
*
* @author  Benjamin ISNARD (Benjamin.Isnard@ens-lyon.fr)
*
* @section Licence
 *
 * Copyright ENS Lyon, INRIA, UCBL, SysFera (2000)
 *
 * - Frederic.Desprez@ens-lyon.fr (Project Manager)
 * - Eddy.Caron@ens-lyon.fr (Technical Manager)
 * - Tech@sysfera.com (Maintainer and Technical Support)
 *
 * This software is a computer program whose purpose is to provide an
 * easy and transparent access to distributed and heterogeneous
 * platforms.
 *
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided
 * only with a limited warranty  and the software's author,  the holder
 * of the economic rights,  and the successive licensors  have only
 * limited liability.
 *
 * In this respect, the user's attention is drawn to the risks
 * associated with loading,  using,  modifying and/or developing or
 * reproducing the software by the user in light of its specific status
 * of free software, that may mean  that it is complicated to
 * manipulate, and  that  also therefore means  that it is reserved for
 * developers and experienced professionals having in-depth computer
 * knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions
 * enabling the security of their systems and/or data to be ensured and,
 * more generally, to use and operate it in the same conditions as
 * regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
*/


#include "DagNodeLauncher.hh"
#include "DagNode.hh"
#include <boost/format.hpp>

DagNodeLauncher::DagNodeLauncher(DagNode * parent,
                                 DagScheduler * scheduler)
  : myNode(parent), myDagScheduler(scheduler),
    isSeDDefinedFlag(false), myReqID(0),
    isSuccessfulFlag(false) {
  myChosenServer = NULL;
}

void
DagNodeLauncher::setSeD(const char* sed, const unsigned long reqID,
                        corba_estimation_t& ev) {
  myChosenServer = CORBA::string_dup(sed);
  myReqID = reqID;
  myEstimVect = ev;  // COPY of estimation vector (required)
  isSeDDefinedFlag = true;
}

// FIXME should return the hostname not the dataMgr name (temp for gwendia exp.)
std::string
DagNodeLauncher::getSeDName() const {
  if (isSeDDefined()) {
    return myChosenServer;
  } else {
    return "";
  }
}


std::string
DagNodeLauncher::toString() const {
  boost::format fmter("DagNode Launcher (%1%)");
  return boost::str(fmter % myNode->getId());
}


void *
DagNodeLauncher::run() {
  execNode();
  if (isSuccessfulFlag) {
    myNode->setAsDone(myDagScheduler);
  } else {
    myNode->setAsFailed(myDagScheduler);
  }
  finishNode();
  return NULL;
};

void
DagNodeLauncher::finishNode() {
}
